@@ -73,7 +73,7 @@ class BernoulliProbs(Distribution):
     support = constraints.boolean
     has_enumerate_support = True
 
-    def __init__(self, probs, validate_args=None):
+    def __init__(self, probs, *, validate_args=None):
         self.probs = probs
         super(BernoulliProbs, self).__init__(
             batch_shape=jnp.shape(self.probs), validate_args=validate_args
@@ -115,7 +115,7 @@ class BernoulliLogits(Distribution):
     support = constraints.boolean
     has_enumerate_support = True
 
-    def __init__(self, logits=None, validate_args=None):
+    def __init__(self, logits=None, *, validate_args=None):
         self.logits = logits
         super(BernoulliLogits, self).__init__(
             batch_shape=jnp.shape(self.logits), validate_args=validate_args
@@ -151,7 +151,7 @@ class BernoulliLogits(Distribution):
         return values
 
 
-def Bernoulli(probs=None, logits=None, validate_args=None):
+def Bernoulli(probs=None, logits=None, *, validate_args=None):
     if probs is not None:
         return BernoulliProbs(probs, validate_args=validate_args)
     elif logits is not None:
@@ -167,7 +167,7 @@ class BinomialProbs(Distribution):
     }
     has_enumerate_support = True
 
-    def __init__(self, probs, total_count=1, validate_args=None):
+    def __init__(self, probs, total_count=1, *, validate_args=None):
         self.probs, self.total_count = promote_shapes(probs, total_count)
         batch_shape = lax.broadcast_shapes(jnp.shape(probs), jnp.shape(total_count))
         super(BinomialProbs, self).__init__(
@@ -185,12 +185,13 @@ class BinomialProbs(Distribution):
         log_factorial_n = gammaln(self.total_count + 1)
         log_factorial_k = gammaln(value + 1)
         log_factorial_nmk = gammaln(self.total_count - value + 1)
+        probs = clamp_probs(self.probs)
         return (
             log_factorial_n
             - log_factorial_k
             - log_factorial_nmk
-            + xlogy(value, self.probs)
-            + xlog1py(self.total_count - value, -self.probs)
+            + xlogy(value, probs)
+            + xlog1py(self.total_count - value, -probs)
         )
 
     @lazy_property
@@ -237,7 +238,7 @@ class BinomialLogits(Distribution):
     has_enumerate_support = True
     enumerate_support = BinomialProbs.enumerate_support
 
-    def __init__(self, logits, total_count=1, validate_args=None):
+    def __init__(self, logits, total_count=1, *, validate_args=None):
         self.logits, self.total_count = promote_shapes(logits, total_count)
         batch_shape = lax.broadcast_shapes(jnp.shape(logits), jnp.shape(total_count))
         super(BinomialLogits, self).__init__(
@@ -283,7 +284,7 @@ class BinomialLogits(Distribution):
         return constraints.integer_interval(0, self.total_count)
 
 
-def Binomial(total_count=1, probs=None, logits=None, validate_args=None):
+def Binomial(total_count=1, probs=None, logits=None, *, validate_args=None):
     if probs is not None:
         return BinomialProbs(probs, total_count, validate_args=validate_args)
     elif logits is not None:
@@ -296,7 +297,7 @@ class CategoricalProbs(Distribution):
     arg_constraints = {"probs": constraints.simplex}
     has_enumerate_support = True
 
-    def __init__(self, probs, validate_args=None):
+    def __init__(self, probs, *, validate_args=None):
         if jnp.ndim(probs) < 1:
             raise ValueError("`probs` parameter must be at least one-dimensional.")
         self.probs = probs
@@ -346,7 +347,7 @@ class CategoricalLogits(Distribution):
     arg_constraints = {"logits": constraints.real_vector}
     has_enumerate_support = True
 
-    def __init__(self, logits, validate_args=None):
+    def __init__(self, logits, *, validate_args=None):
         if jnp.ndim(logits) < 1:
             raise ValueError("`logits` parameter must be at least one-dimensional.")
         self.logits = logits
@@ -394,7 +395,7 @@ class CategoricalLogits(Distribution):
         return values
 
 
-def Categorical(probs=None, logits=None, validate_args=None):
+def Categorical(probs=None, logits=None, *, validate_args=None):
     if probs is not None:
         return CategoricalProbs(probs, validate_args=validate_args)
     elif logits is not None:
@@ -407,7 +408,7 @@ class DiscreteUniform(Distribution):
     arg_constraints = {"low": constraints.dependent, "high": constraints.dependent}
     has_enumerate_support = True
 
-    def __init__(self, low=0, high=1, validate_args=None):
+    def __init__(self, low=0, high=1, *, validate_args=None):
         self.low, self.high = promote_shapes(low, high)
         batch_shape = lax.broadcast_shapes(jnp.shape(low), jnp.shape(high))
         self._support = constraints.integer_interval(low, high)
@@ -481,7 +482,7 @@ class OrderedLogistic(CategoricalProbs):
         "cutpoints": constraints.ordered_vector,
     }
 
-    def __init__(self, predictor, cutpoints, validate_args=None):
+    def __init__(self, predictor, cutpoints, *, validate_args=None):
         if jnp.ndim(predictor) == 0:
             (predictor,) = promote_shapes(predictor, shape=(1,))
         else:
@@ -504,7 +505,7 @@ class MultinomialProbs(Distribution):
         "total_count": constraints.nonnegative_integer,
     }
 
-    def __init__(self, probs, total_count=1, validate_args=None):
+    def __init__(self, probs, total_count=1, *, validate_args=None):
         if jnp.ndim(probs) < 1:
             raise ValueError("`probs` parameter must be at least one-dimensional.")
         batch_shape, event_shape = self.infer_shapes(
@@ -561,7 +562,7 @@ class MultinomialLogits(Distribution):
         "total_count": constraints.nonnegative_integer,
     }
 
-    def __init__(self, logits, total_count=1, validate_args=None):
+    def __init__(self, logits, total_count=1, *, validate_args=None):
         if jnp.ndim(logits) < 1:
             raise ValueError("`logits` parameter must be at least one-dimensional.")
         batch_shape, event_shape = self.infer_shapes(
@@ -617,7 +618,7 @@ class MultinomialLogits(Distribution):
         return batch_shape, event_shape
 
 
-def Multinomial(total_count=1, probs=None, logits=None, validate_args=None):
+def Multinomial(total_count=1, probs=None, logits=None, *, validate_args=None):
     if probs is not None:
         return MultinomialProbs(probs, total_count, validate_args=validate_args)
     elif logits is not None:
@@ -795,7 +796,7 @@ class ZeroInflatedPoisson(ZeroInflatedProbs):
 
     # TODO: resolve inconsistent parameter order w.r.t. Pyro
     # and support `gate_logits` argument
-    def __init__(self, gate, rate=1.0, validate_args=None):
+    def __init__(self, gate, rate=1.0, *, validate_args=None):
         _, self.rate = promote_shapes(gate, rate)
         super().__init__(Poisson(self.rate), gate, validate_args=validate_args)
 
@@ -804,7 +805,7 @@ class GeometricProbs(Distribution):
     arg_constraints = {"probs": constraints.unit_interval}
     support = constraints.nonnegative_integer
 
-    def __init__(self, probs, validate_args=None):
+    def __init__(self, probs, *, validate_args=None):
         self.probs = probs
         super(GeometricProbs, self).__init__(
             batch_shape=jnp.shape(self.probs), validate_args=validate_args
@@ -840,7 +841,7 @@ class GeometricLogits(Distribution):
     arg_constraints = {"logits": constraints.real}
     support = constraints.nonnegative_integer
 
-    def __init__(self, logits, validate_args=None):
+    def __init__(self, logits, *, validate_args=None):
         self.logits = logits
         super(GeometricLogits, self).__init__(
             batch_shape=jnp.shape(self.logits), validate_args=validate_args
@@ -871,7 +872,7 @@ class GeometricLogits(Distribution):
         return (1.0 / self.probs - 1.0) / self.probs
 
 
-def Geometric(probs=None, logits=None, validate_args=None):
+def Geometric(probs=None, logits=None, *, validate_args=None):
     if probs is not None:
         return GeometricProbs(probs, validate_args=validate_args)
     elif logits is not None:
