@@ -86,6 +86,11 @@ COERCIONS = []
 
 
 class DistributionMeta(type):
+    def __init__(cls, *args, **kwargs):
+        signature = inspect.signature(functools.partial(cls.__init__, None))
+        cls.__signature__ = signature
+        return super().__init__(*args, **kwargs)
+
     def __call__(cls, *args, **kwargs):
         for coerce_ in COERCIONS:
             result = coerce_(cls, args, kwargs)
@@ -93,10 +98,6 @@ class DistributionMeta(type):
                 return result
         return super().__call__(*args, **kwargs)
 
-    @property
-    def __wrapped__(cls):
-        return functools.partial(cls.__init__, None)
-
 
 class Distribution(metaclass=DistributionMeta):
     """
@@ -157,7 +158,7 @@ class Distribution(metaclass=DistributionMeta):
             raise ValueError
         Distribution._validate_args = value
 
-    def __init__(self, batch_shape=(), event_shape=(), validate_args=None):
+    def __init__(self, batch_shape=(), event_shape=(), *, validate_args=None):
         self._batch_shape = batch_shape
         self._event_shape = event_shape
         if validate_args is not None:
@@ -679,7 +680,7 @@ class ImproperUniform(Distribution):
     arg_constraints = {}
     support = constraints.dependent
 
-    def __init__(self, support, batch_shape, event_shape, validate_args=None):
+    def __init__(self, support, batch_shape, event_shape, *, validate_args=None):
         self.support = constraints.independent(
             support, len(event_shape) - support.event_dim
         )
@@ -733,7 +734,7 @@ class Independent(Distribution):
 
     arg_constraints = {}
 
-    def __init__(self, base_dist, reinterpreted_batch_ndims, validate_args=None):
+    def __init__(self, base_dist, reinterpreted_batch_ndims, *, validate_args=None):
         if reinterpreted_batch_ndims > len(base_dist.batch_shape):
             raise ValueError(
                 "Expected reinterpreted_batch_ndims <= len(base_distribution.batch_shape), "
@@ -921,7 +922,7 @@ class TransformedDistribution(Distribution):
 
     arg_constraints = {}
 
-    def __init__(self, base_distribution, transforms, validate_args=None):
+    def __init__(self, base_distribution, transforms, *, validate_args=None):
         if isinstance(transforms, Transform):
             transforms = [transforms]
         elif isinstance(transforms, list):
@@ -1063,7 +1064,7 @@ class FoldedDistribution(TransformedDistribution):
 
     support = constraints.positive
 
-    def __init__(self, base_dist, validate_args=None):
+    def __init__(self, base_dist, *, validate_args=None):
         if base_dist.event_shape:
             raise ValueError("Only univariate distributions can be folded.")
         super().__init__(base_dist, AbsTransform(), validate_args=validate_args)
@@ -1092,7 +1093,7 @@ class Delta(Distribution):
     }
     reparametrized_params = ["v", "log_density"]
 
-    def __init__(self, v=0.0, log_density=0.0, event_dim=0, validate_args=None):
+    def __init__(self, v=0.0, log_density=0.0, event_dim=0, *, validate_args=None):
         if event_dim > jnp.ndim(v):
             raise ValueError(
                 "Expected event_dim <= v.dim(), actual {} vs {}".format(
@@ -1151,7 +1152,7 @@ class Unit(Distribution):
     arg_constraints = {"log_factor": constraints.real}
     support = constraints.real
 
-    def __init__(self, log_factor, validate_args=None):
+    def __init__(self, log_factor, *, validate_args=None):
         batch_shape = jnp.shape(log_factor)
         event_shape = (0,)  # This satisfies .size == 0.
         self.log_factor = log_factor
