@@ -13,6 +13,7 @@ from numpyro.distributions.kl import kl_divergence
 from numpyro.distributions.util import scale_and_mask
 from numpyro.handlers import replay, seed, substitute, trace
 from numpyro.infer.util import get_importance_trace, log_density
+from numpyro.util import _validate_model, check_model_guide_match, find_stack_level
 
 
 class ELBO:
@@ -25,6 +26,13 @@ class ELBO:
         (gradient) estimators.
     """
 
+    """
+    Determines whether the ELBO objective can support inference of discrete latent variables.
+
+    Subclasses that are capable of inferring  discrete latent variables should override to `True`
+    """
+    can_infer_discrete = False
+
     def __init__(self, num_particles=1):
         self.num_particles = num_particles
 
@@ -117,6 +125,8 @@ class Trace_ELBO(ELBO):
             model_log_density, model_trace = log_density(
                 seeded_model, args, kwargs, params
             )
+            check_model_guide_match(model_trace, guide_trace)
+            _validate_model(model_trace, plate_warning="loose")
             mutable_params.update(
                 {
                     name: site["value"]
@@ -181,8 +191,9 @@ def _check_mean_field_requirement(model_trace, guide_trace):
             + "Model sites:\n  "
             + "\n  ".join(model_sites)
             + "Guide sites:\n  "
-            + "\n  ".join(guide_sites)
-        )
+            + "\n  ".join(guide_sites),
+            stacklevel=find_stack_level(),
+        ),
 
 
 class TraceMeanField_ELBO(ELBO):
@@ -228,6 +239,8 @@ class TraceMeanField_ELBO(ELBO):
                     if site["type"] == "mutable"
                 }
             )
+            check_model_guide_match(model_trace, guide_trace)
+            _validate_model(model_trace, plate_warning="loose")
             _check_mean_field_requirement(model_trace, guide_trace)
 
             elbo_particle = 0
@@ -251,7 +264,7 @@ class TraceMeanField_ELBO(ELBO):
             # handle auxiliary sites in the guide
             for name, site in guide_trace.items():
                 if site["type"] == "sample" and name not in model_trace:
-                    assert site["infer"].get("is_auxiliary")
+                    assert site["infer"].get("is_auxiliary") or site["is_observed"]
                     elbo_particle = elbo_particle - _get_log_prob_sum(site)
 
             if mutable_params:
@@ -318,9 +331,11 @@ class RenyiELBO(ELBO):
                 k: v for k, v in param_map.items() if k not in guide_trace
             }
             seeded_model = replay(seeded_model, guide_trace)
-            model_log_density, _ = log_density(
+            model_log_density, model_trace = log_density(
                 seeded_model, args, kwargs, model_param_map
             )
+            check_model_guide_match(model_trace, guide_trace)
+            _validate_model(model_trace, plate_warning="loose")
 
             # log p(z) - log q(z)
             elbo = model_log_density - guide_log_density
@@ -531,6 +546,8 @@ class TraceGraph_ELBO(ELBO):
         John Schulman, Nicolas Heess, Theophane Weber, Pieter Abbeel
     """
 
+    can_infer_discrete = True
+
     def __init__(self, num_particles=1):
         super().__init__(num_particles=num_particles)
 
@@ -557,6 +574,8 @@ class TraceGraph_ELBO(ELBO):
             model_trace, guide_trace = get_importance_trace(
                 seeded_model, seeded_guide, args, kwargs, param_map
             )
+            check_model_guide_match(model_trace, guide_trace)
+            _validate_model(model_trace, plate_warning="strict")
 
             # XXX: different from Pyro, we don't support baseline_loss here
             non_reparam_nodes = {
