@@ -3,14 +3,14 @@
 
 
 def patch_dependency(target, root_module):
-    parts = target.split('.')
+    parts = target.split(".")
     assert parts[0] == root_module.__name__
     module = root_module
     for part in parts[1:-1]:
         module = getattr(module, part)
     name = parts[-1]
     old_fn = getattr(module, name)
-    old_fn = getattr(old_fn, '_pyro_unpatched', old_fn)  # ensure patching is idempotent
+    old_fn = getattr(old_fn, "_pyro_unpatched", old_fn)  # ensure patching is idempotent
 
     def decorator(new_fn):
         new_fn.__name__ = name
