@@ -7,8 +7,16 @@ import numpy as np
 from numpy.testing import assert_allclose, assert_array_equal
 import pytest
 
+import jax
 from jax import jacfwd, random, vmap
-from jax.experimental.stax import serial
+
+from numpyro.util import _versiontuple
+
+if _versiontuple(jax.__version__) >= (0, 2, 25):
+    from jax.example_libraries.stax import serial
+else:
+    from jax.experimental.stax import serial
+
 import jax.numpy as jnp
 
 from numpyro.distributions.util import matrix_to_tril_vec
